@@ -482,6 +482,9 @@ def _validate_emr_args(args, usage, kernel_name):
     if args.assumable_role_arn:
         RoleArnValidator.validate(args.assumable_role_arn)
 
+    if args.emr_execution_role_arn:
+        RoleArnValidator.validate(args.emr_execution_role_arn)
+
     # Only IPython kernel needs language option support
     if kernel_name == IPYTHON_KERNEL:
         if args.language is None:
